;; Generated package description from transcribe.el  -*- no-byte-compile: t -*-
(define-package "transcribe" "1.5.2.0.20221221.82457" "Package for audio transcriptions" 'nil :commit "2c2d493d5488f3b444d2a771ab443589fcc72c13" :url "https://elpa.gnu.org/packages/transcribe.html" :authors '(("David Gonzalez Gandara" . "dggandara@member.fsf.org")) :maintainer '("David Gonzalez Gandara" . "dggandara@member.fsf.org"))
